@@ -1,6 +1,6 @@
 // Break.cc
 //
-// Copyright (C) 2001 - 2010 Rob Caelers & Raymond Penners
+// Copyright (C) 2001 - 2011 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -269,6 +269,7 @@ Break::init_timer()
 void
 Break::load_timer_config()
 {
+  TRACE_ENTER("Break::load_timer_config");
   // Read break limit.
   int limit;
   config->get_value(CoreConfig::CFG_KEY_TIMER_LIMIT % break_id, limit);
@@ -294,23 +295,19 @@ Break::load_timer_config()
   config->get_value(CoreConfig::CFG_KEY_TIMER_SNOOZE % break_id, snooze);
   timer->set_snooze_interval(snooze);
 
-  // Read the activity insensitive flag
-  //bool sensitive;
-  //config->get_value(CoreConfig::CFG_KEY_TIMER_ACTIVITY_SENSITIVE % break_id, sensitive);
-  //timer->set_activity_sensitive(sensitive);
-  timer->set_activity_sensitive(true);
-
   // Load the monitor setting for the timer.
   string monitor_name;
 
   bool ret = config->get_value(CoreConfig::CFG_KEY_TIMER_MONITOR % break_id, monitor_name);
 
+  TRACE_MSG(ret << " " << monitor_name);
   if (ret && monitor_name != "")
     {
       Core *core = Core::get_instance();
       Timer *master = core->get_timer(monitor_name);
       if (master != NULL)
         {
+          TRACE_MSG("found master timer");
           TimerActivityMonitor *am = new TimerActivityMonitor(master);
           timer->set_activity_monitor(am);
         }
@@ -319,6 +316,7 @@ Break::load_timer_config()
     {
       timer->set_activity_monitor(NULL);
     }
+  TRACE_EXIT();
 }
 
 
@@ -367,10 +365,7 @@ Break::override(BreakId id)
 bool
 Break::get_timer_activity_sensitive() const
 {
-  // bool sensitive;
-  // config->get_value(CoreConfig::CFG_KEY_TIMER_ACTIVITY_SENSITIVE % break_id, sensitive);
-
-  return true; // sensitive;
+  return timer->get_activity_sensitive();
 }
 
 bool
@@ -386,6 +381,13 @@ Break::is_running() const
   return state == STATE_RUNNING;
 }
 
+
+bool
+Break::is_taking() const
+{
+  return break_control->is_taking();
+}
+
 time_t
 Break::get_elapsed_time() const
 {
@@ -433,10 +435,6 @@ Break::set_usage_mode(UsageMode mode)
       TRACE_MSG("changing");
       if (mode == USAGE_MODE_NORMAL)
         {
-          // Read the activity insensitive flag
-          // bool sensitive;
-          // config->get_value(CoreConfig::CFG_KEY_TIMER_ACTIVITY_SENSITIVE % break_id, sensitive);
-          // timer->set_activity_sensitive(sensitive);
           timer->set_activity_sensitive(true);
         }
       else if (mode == USAGE_MODE_READING)
