@@ -1,6 +1,6 @@
 // Core.cc --- The main controller
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -395,6 +395,7 @@ Core::load_monitor_config()
 void
 Core::config_changed_notify(const string &key)
 {
+  TRACE_ENTER_MSG("Core::config_changed_notify", key);
   string::size_type pos = key.find('/');
   string path;
 
@@ -415,6 +416,7 @@ Core::config_changed_notify(const string &key)
         {
           mode = OPERATION_MODE_NORMAL;
         }
+      TRACE_MSG("Setting mode");
       set_operation_mode(OperationMode(mode), false);
     }
 
@@ -427,6 +429,7 @@ Core::config_changed_notify(const string &key)
         }
       set_usage_mode(UsageMode(mode), false);
     }
+  TRACE_EXIT();
 }
 
 
@@ -546,9 +549,13 @@ Core::set_operation_mode(OperationMode mode, bool persistent)
   TRACE_ENTER_MSG("Core::set_operation_mode",
                   (mode == OPERATION_MODE_NORMAL ? "normal" :
                    mode == OPERATION_MODE_SUSPENDED ? "suspended" :
-                   mode == OPERATION_MODE_QUIET ? "quiet" : "???"));
+                   mode == OPERATION_MODE_QUIET ? "quiet" : "???") << " " << persistent);
   
   OperationMode previous_mode = operation_mode;
+
+  TRACE_MSG("Previous " << (mode == OPERATION_MODE_NORMAL ? "normal" :
+                            mode == OPERATION_MODE_SUSPENDED ? "suspended" :
+                            mode == OPERATION_MODE_QUIET ? "quiet" : "???"));
   
   if (operation_mode != mode)
     {
@@ -556,6 +563,7 @@ Core::set_operation_mode(OperationMode mode, bool persistent)
       
       if (operation_mode == OPERATION_MODE_SUSPENDED)
         {
+          TRACE_MSG("Force idle");
           force_idle();
           monitor->suspend();
           stop_all_breaks();
@@ -691,6 +699,7 @@ Core::set_powersave(bool down)
     {
       // Computer is going down
       powersave_operation_mode = set_operation_mode(OPERATION_MODE_SUSPENDED, false);
+      TRACE_MSG("prev mode " << powersave_operation_mode);
       powersave_resume_time = 0;
       powersave = true;
 
@@ -705,8 +714,10 @@ Core::set_powersave(bool down)
       if (powersave_resume_time == 0)
         {
           powersave_resume_time = current_time ? current_time : 1;
+          TRACE_MSG("set resume time " << powersave_resume_time);
         }
 
+      TRACE_MSG("resume time " << powersave_resume_time);
       set_operation_mode(powersave_operation_mode, false);
     }
   TRACE_EXIT();
@@ -752,6 +763,7 @@ Core::get_insist_policy() const
 void
 Core::force_idle()
 {
+  TRACE_ENTER("Core::force_idle");
   monitor->force_idle();
 
   for (int i = 0; i < BREAK_ID_SIZEOF; i++)
@@ -764,6 +776,7 @@ Core::force_idle()
 
       breaks[i].get_timer()->force_idle();
     }
+  TRACE_EXIT();
 }
 
 
@@ -1116,7 +1129,7 @@ Core::process_timers()
   TRACE_EXIT();
 }
 
-#ifdef PLATFORM_OS_WIN32
+#if defined(PLATFORM_OS_WIN32)
 
 //! Process a possible timewarp on Win32
 bool
@@ -1678,7 +1691,7 @@ Core::request_break_state(PacketBuffer &buffer)
           int pos = buffer.bytes_written();
 
           buffer.pack_ushort(0);
-          buffer.pack_byte((guint8)state_data.user_initiated);
+          buffer.pack_byte((guint8)state_data.forced_break);
           buffer.pack_byte((guint8)state_data.reached_max_prelude);
           buffer.pack_ulong((guint32)state_data.prelude_count);
           buffer.pack_ulong((guint32)state_data.break_stage);
@@ -1716,7 +1729,7 @@ Core::set_break_state(bool master, PacketBuffer &buffer)
 
       if (data_size > 0)
         {
-          state_data.user_initiated = buffer.unpack_byte();
+          state_data.forced_break = buffer.unpack_byte();
           state_data.reached_max_prelude = buffer.unpack_byte();
           state_data.prelude_count = buffer.unpack_ulong();
           state_data.break_stage = buffer.unpack_ulong();
@@ -1866,12 +1879,16 @@ Core::signon_remote_client(string client_id)
 void
 Core::signoff_remote_client(string client_id)
 {
+  TRACE_ENTER_MSG("Core::signoff_remote_client", client_id);
+  TRACE_MSG("Master = " << dist_manager->get_master_id());
   if (client_id == dist_manager->get_master_id())
     {
+      TRACE_MSG("Idle");
       remote_state = ACTIVITY_IDLE;
     }
 
   idlelog_manager->signoff_remote_client(client_id);
+  TRACE_EXIT();
 }
 
 
