@@ -1,6 +1,6 @@
 // DistributionSocketLink.cc
 //
-// Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010 Rob Caelers <robc@krandor.org>
+// Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2011 Rob Caelers <robc@krandor.org>
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -663,7 +663,7 @@ DistributionSocketLink::set_client_id(Client *client, gchar *id)
       g_free(client->hostname);
       client->id = g_strdup(id);
       client->hostname = NULL;
-      client->port = NULL;
+      client->port = 0;
 
       if (client->id != NULL)
         {
@@ -688,16 +688,15 @@ DistributionSocketLink::remove_client(Client *client)
 {
   list<Client *>::iterator i = clients.begin();
 
-  if (client == master_client)
-    {
-      // Client to be removed is master. Unset master client.
-      master_client = NULL;
-    }
-
   while (i != clients.end())
     {
       if (client == NULL || *i == client || (*i)->peer == client)
         {
+          if ((*i)->id != NULL)
+            {
+              dist_manager->signoff_remote_client((*i)->id);
+            }
+          
           dist_manager->log(_("Removing client %s."),
                             (*i)->id == NULL ? "Unknown" : (*i)->id);
           delete *i;
@@ -708,6 +707,12 @@ DistributionSocketLink::remove_client(Client *client)
           i++;
         }
     }
+
+  if (client == master_client)
+    {
+      // Client to be removed is master. Unset master client.
+      master_client = NULL;
+    }
 }
 
 
@@ -728,6 +733,11 @@ DistributionSocketLink::remove_peer_clients(Client *client)
                             (*i)->id == NULL ? "Unknown" : (*i)->id);
           send_signoff(NULL, *i);
 
+          if ((*i)->id != NULL)
+            {
+              dist_manager->signoff_remote_client((*i)->id);
+            }
+          
           if (client == master_client)
             {
               // Connection to master is lost. Unset master client.
@@ -753,6 +763,11 @@ DistributionSocketLink::close_client(Client *client, bool reconnect /* = false*/
   TRACE_ENTER_MSG("DistributionSocketLink::close_client", 
 	  (client->id != NULL ? client->id : "Unknown") << " " << reconnect);
 
+  if (client->id != NULL)
+    {
+      dist_manager->signoff_remote_client(client->id);
+    }
+  
   if (client == master_client)
     {
       // Client to be closed is master. Unset master client.
@@ -899,7 +914,7 @@ DistributionSocketLink::set_master(Client *client)
 
   if (dist_manager != NULL)
     {
-      dist_manager->master_changed(false, client != NULL ? client->id : NULL);
+      dist_manager->master_changed(false, client != NULL ? client->id : "");
     }
   TRACE_EXIT();
 }
@@ -1372,13 +1387,15 @@ DistributionSocketLink::handle_signoff(PacketBuffer &packet, Client *client)
           TRACE_MSG("Direct connection. setting signedoff");
           c->type = CLIENTTYPE_SIGNEDOFF;
           remove_peer_clients(c);
-
+          
           if (c->socket != NULL)
             {
               TRACE_MSG("Remove connection");
               delete c->socket;
               c->socket = NULL;
             }
+
+          remove_client(c);
         }
       else
         {
