@@ -1,6 +1,6 @@
 // X11InputMonitor.cc --- ActivityMonitor for X11
 //
-// Copyright (C) 2001-2007, 2009 Rob Caelers <robc@krandor.nl>
+// Copyright (C) 2001-2007, 2009, 2010 Rob Caelers <robc@krandor.nl>
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -65,20 +65,29 @@
 #include <X11/Xos.h>
 
 #include "X11InputMonitor.hh"
+
+#include "Core.hh"
+#include "ICore.hh"
+#include "ICoreEventListener.hh"
 #include "IInputMonitorListener.hh"
 
 #include "timeutil.h"
 
 #ifdef HAVE_APP_GTK
-#include <gdk/gdk.h>
+#include <gdk/gdkx.h>
 #endif
 
 #include "Thread.hh"
 
 using namespace std;
+using namespace workrave;
 
 int X11InputMonitor::xi_event_base = 0;
 
+#ifndef HAVE_APP_GTK
+static int (*old_handler)(Display *dpy, XErrorEvent *error);
+#endif
+
 #ifndef HAVE_APP_GTK
 //! Intercepts X11 protocol errors.
 static int
@@ -92,6 +101,7 @@ errorHandler(Display *dpy, XErrorEvent *error)
 }
 #endif
 
+#ifdef HAVE_XRECORD_FALLBACK
 //! Obtains the next X11 event with specified timeout.
 static Bool
 XNextEventTimed(Display* dsp, XEvent* event_return, long millis)
@@ -136,20 +146,18 @@ XNextEventTimed(Display* dsp, XEvent* event_return, long millis)
         }
     }
 }
-
+#endif
 
 X11InputMonitor::X11InputMonitor(const string &display_name) :
   x11_display(NULL),
   abort(false)
 {
-#ifdef HAVE_XRECORD
   use_xrecord = false;
   xrecord_context = 0;
   xrecord_datalink = NULL;
-#endif
 
   x11_display_name = display_name;
-  monitor_thread = new Thread(this); // FIXME: LEAK
+  monitor_thread = new Thread(this);
 }
 
 
@@ -163,12 +171,10 @@ X11InputMonitor::~X11InputMonitor()
       delete monitor_thread;
     }
 
-#ifdef HAVE_XRECORD
   if (xrecord_datalink != NULL)
     {
       XCloseDisplay(xrecord_datalink);
     }
-#endif
   TRACE_EXIT();
 }
 
@@ -185,22 +191,14 @@ X11InputMonitor::terminate()
 {
   TRACE_ENTER("X11InputMonitor::terminate");
 
-#ifdef HAVE_XRECORD
   if (use_xrecord)
     {
       stop_xrecord();
     }
-#endif
 
   abort = true;
+  monitor_thread->wait();
 
-#ifdef HAVE_XRECORD
-  //FIXME:  stop_xrecord does not seem to work.
-  if (use_xrecord)
-    {
-      monitor_thread->wait();
-    }
-#endif
   TRACE_EXIT();
 }
 
@@ -215,42 +213,34 @@ X11InputMonitor::run()
       return;
     }
 
-#ifdef HAVE_XRECORD
   run_xrecord();
-#else
-  run_events();
-  XCloseDisplay(x11_display);
-#endif
 
   TRACE_EXIT();
 }
 
+#ifdef HAVE_XRECORD_FALLBACK  
+
 void
 X11InputMonitor::run_events()
 {
   TRACE_ENTER("X11InputMonitor::run_events");
 
+  if (x11_display == NULL)
+    {
+      return;
+    }
+  
+  error_trap_enter();
+  
   root_window = DefaultRootWindow(x11_display);
-
   set_all_events(root_window);
 
-#ifdef HAVE_APP_GTK
-  gdk_error_trap_push();
-#else
-  int (*old_handler)(Display *dpy, XErrorEvent *error);
-  old_handler = XSetErrorHandler(&errorHandler);
-#endif
-
   XGrabButton(x11_display, AnyButton, AnyModifier, root_window, True,
               ButtonPressMask, GrabModeSync, GrabModeAsync, None, None);
   XSync(x11_display,False);
 
-#ifdef HAVE_APP_GTK
-  gdk_error_trap_pop();
-#else
-  XSetErrorHandler(old_handler);
-#endif
-
+  error_trap_exit();
+  
   Window lastMouseRoot = 0;
   while (1)
     {
@@ -265,6 +255,8 @@ X11InputMonitor::run_events()
 
       if (gotEvent)
         {
+          error_trap_enter();
+          
           switch (event.xany.type)
             {
             case KeyPress:
@@ -280,15 +272,22 @@ X11InputMonitor::run_events()
               handle_button(&event);
               break;
             }
+
+          error_trap_exit();
         }
 
+      
       // timeout
       Window root, child;
       int root_x, root_y, win_x, win_y;
       unsigned mask;
 
+      error_trap_enter();
+      
       XQueryPointer(x11_display, root_window, &root, &child, &root_x, &root_y, &win_x, &win_y, &mask);
 
+      error_trap_exit();
+      
       lastMouseRoot = root;
       fire_mouse(root_x, root_y);
     }
@@ -342,22 +341,12 @@ X11InputMonitor::set_event_mask(Window window)
 void
 X11InputMonitor::set_all_events(Window window)
 {
-
-#ifdef HAVE_APP_GTK
-  gdk_error_trap_push();
-#else
-  int (*old_handler)(Display *dpy, XErrorEvent *error);
-  old_handler = XSetErrorHandler(&errorHandler);
-#endif
-
+  error_trap_enter();
+  
   set_event_mask(window);
   XSync(x11_display,False);
 
-#ifdef HAVE_APP_GTK
-  gdk_error_trap_pop();
-#else
-  XSetErrorHandler(old_handler);
-#endif
+  error_trap_exit();
 }
 
 
@@ -365,7 +354,7 @@ void
 X11InputMonitor::handle_keypress(XEvent *event)
 {
   (void) event;
-  fire_keyboard(0, 0);
+  fire_keyboard(false);
 }
 
 
@@ -387,12 +376,11 @@ X11InputMonitor::handle_button(XEvent *event)
 
   if (event != NULL)
     {
-      int b = event->xbutton.button;
       // FIXME: this is a hack. XGrabButton does not generate a button release
       // event...
 
-      fire_button(b, true);
-      fire_button(b, false);
+      fire_button(true);
+      fire_button(false);
     }
   else
     {
@@ -400,15 +388,35 @@ X11InputMonitor::handle_button(XEvent *event)
     }
 }
 
+#endif // HAVE_XRECORD_FALLBACK
 
+void
+X11InputMonitor::error_trap_enter()
+{
+#ifdef HAVE_APP_GTK
+  gdk_error_trap_push();
+#else
+  old_handler = XSetErrorHandler(&errorHandler);
+#endif
+}
 
-#ifdef HAVE_XRECORD
+void
+X11InputMonitor::error_trap_exit()
+{
+#ifdef HAVE_APP_GTK
+  gdk_flush ();
+  gdk_error_trap_pop();
+#else
+  XSetErrorHandler(old_handler);
+#endif
+}
+  
 
 void
 X11InputMonitor::handle_xrecord_handle_key_event(XRecordInterceptData *data)
 {
   (void) data;
-  fire_keyboard(0, 0);
+  fire_keyboard(false);
 }
 
 void
@@ -436,9 +444,7 @@ X11InputMonitor::handle_xrecord_handle_button_event(XRecordInterceptData *data)
 
   if (event != NULL)
     {
-      int b = event->u.keyButtonPointer.state;
-
-      fire_button(b, event->u.u.type == ButtonPress);
+      fire_button(event->u.u.type == ButtonPress);
     }
   else
     {
@@ -447,16 +453,30 @@ X11InputMonitor::handle_xrecord_handle_button_event(XRecordInterceptData *data)
 }
 
 void
-X11InputMonitor::handle_xrecord_handle_device_key_event(XRecordInterceptData *data)
+X11InputMonitor::handle_xrecord_handle_device_key_event(bool press, XRecordInterceptData *data)
 {
   TRACE_ENTER("X11InputMonitor::handle_xrecord_handle_device_key_event");
   deviceKeyButtonPointer *event = (deviceKeyButtonPointer *)data->data;
   static Time lastTime = 0;
-
-  if (event->time != lastTime)
+  static int detail = 0;
+  static int state = 0;
+  
+  if (press)
     {
-      lastTime = event->time;
-      fire_keyboard(0, 0);
+      if (event->time != lastTime)
+        {
+          lastTime = event->time;
+
+          fire_keyboard(state == event->state && detail == event->detail);
+
+          detail = event->detail;
+          state = event->state;
+        }
+    }
+  else
+    {
+      detail = 0;
+      state = 0;
     }
   
   TRACE_EXIT();
@@ -488,10 +508,7 @@ X11InputMonitor::handle_xrecord_handle_device_button_event(XRecordInterceptData
     {
       lastTime = event->time;
 
-      // FIXME: check if this is correct
-      int b = event->state;
-      
-      fire_button(b, event->type == xi_event_base + XI_DeviceButtonPress);
+      fire_button(event->type == xi_event_base + XI_DeviceButtonPress);
     }
 }
 
@@ -527,7 +544,11 @@ X11InputMonitor::handle_xrecord_callback(XPointer closure, XRecordInterceptData
             }
           else if (event->u.u.type == xi_event_base + XI_DeviceKeyPress)
             {
-              monitor->handle_xrecord_handle_device_key_event(data);
+              monitor->handle_xrecord_handle_device_key_event(true, data);
+            }
+          else if (event->u.u.type == xi_event_base + XI_DeviceKeyRelease)
+            {
+              monitor->handle_xrecord_handle_device_key_event(false, data);
             }
           else if (event->u.u.type == xi_event_base + XI_DeviceButtonPress ||
                    event->u.u.type == xi_event_base + XI_DeviceButtonRelease)
@@ -552,16 +573,24 @@ X11InputMonitor::run_xrecord()
 
   init_xrecord();
 
+  error_trap_enter();
+  
   if (use_xrecord &&
       XRecordEnableContext(xrecord_datalink, xrecord_context,  &handle_xrecord_callback, (XPointer)this))
     {
+      error_trap_exit();
       xrecord_datalink = NULL;
     }
   else
     {
+#ifdef HAVE_XRECORD_FALLBACK  
+      error_trap_exit();
       TRACE_MSG("Fallback to run events");
       use_xrecord = false;
       run_events();
+#else
+      g_idle_add(static_report_failure, NULL);
+#endif      
     }
   TRACE_EXIT();
 }
@@ -646,10 +675,21 @@ X11InputMonitor::stop_xrecord()
       XRecordFreeContext(x11_display, xrecord_context);
       XFlush(xrecord_datalink);
       XCloseDisplay(x11_display);
+      x11_display = NULL;
     }
 
   TRACE_EXIT();
   return true;
 }
 
-#endif
+
+gboolean
+X11InputMonitor::static_report_failure(void *data)
+{
+  (void) data;
+
+  Core *core = Core::get_instance();
+  core->post_event(CORE_EVENT_MONITOR_FAILURE);
+
+  return FALSE;
+}
