@@ -1,6 +1,6 @@
 // BreakWindow.cc --- base class for the break windows
 //
-// Copyright (C) 2001 - 2010 Rob Caelers & Raymond Penners
+// Copyright (C) 2001 - 2011 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -28,6 +28,12 @@
 #include <gdk/gdkwin32.h>
 #endif
 
+#include <gdk/gdkkeysyms.h>
+
+#include <gdk/gdkkeysyms.h>
+
+#include <gdk/gdkkeysyms.h>
+
 #include "preinclude.h"
 #include "debug.hh"
 #include "nls.h"
@@ -40,6 +46,8 @@
 #include <gtkmm/stock.h>
 #include <gtkmm/buttonbox.h>
 #include <gtkmm/button.h>
+#include <gtkmm/enums.h>
+#include <gdkmm/types.h>
 
 #include <math.h>
 
@@ -89,7 +97,12 @@ BreakWindow::BreakWindow(BreakId break_id, HeadInfo &head,
   frame(NULL),
   break_response(NULL),
   gui(NULL),
-  visible(false)
+  visible(false),
+  accel_added(false),
+  postpone_button(NULL),
+  skip_button(NULL),
+  lock_button(NULL),
+  shutdown_button(NULL)
 {
   TRACE_ENTER("BreakWindow::BreakWindow");
   this->break_id = break_id;
@@ -134,22 +147,22 @@ BreakWindow::BreakWindow(BreakId break_id, HeadInfo &head,
   HWND _hParent = GetAncestor( _hwnd, GA_PARENT );
   HWND _hDesktop = GetDesktopWindow();
   
-  TRACE_MSG("BreakWindow created" <<  hex << _hwnd);
+  TRACE_MSG("BreakWindow created" <<  hex << _hwnd << dec);
   if (_hwnd != _scope)
     {
-      TRACE_MSG("!!! Scope issue: " << hex << _scope);
+      TRACE_MSG("!!! Scope issue: " << hex << _scope << dec);
     }
   
   if (_hwnd != _hRoot)
     {
-      TRACE_MSG("GetDesktopWindow()" <<  hex << _hDesktop);
-      TRACE_MSG("!!! BreakWindow GA_ROOT: " << hex << _hRoot);
+      TRACE_MSG("GetDesktopWindow()" <<  hex << _hDesktop << dec);
+      TRACE_MSG("!!! BreakWindow GA_ROOT: " << hex << _hRoot << dec);
     }
   
   if (_hParent != _hDesktop)
     {
-      TRACE_MSG("GetDesktopWindow()" <<  hex << _hDesktop);
-      TRACE_MSG("!!! PreludeWindow GA_PARENT: " << hex << _hParent);
+      TRACE_MSG("GetDesktopWindow()" <<  hex << _hDesktop << dec);
+      TRACE_MSG("!!! PreludeWindow GA_PARENT: " << hex << _hParent << dec);
       
       HWND _hTemp;
       while( IsWindow( _hParent ) && _hParent != _hDesktop )
@@ -159,8 +172,8 @@ BreakWindow::BreakWindow(BreakId break_id, HeadInfo &head,
           HWND _hParent2 = (HWND)GetWindowLong( _hTemp, GWL_HWNDPARENT );
           if( _hParent == _hTemp )
             break;
-          TRACE_MSG("!!!" <<  hex << _hTemp << " GA_PARENT: " << hex << _hParent);
-          TRACE_MSG("!!!" <<  hex << _hTemp << " GWL_HWNDPARENT: " << hex << _hParent2);
+          TRACE_MSG("!!!" <<  hex << _hTemp << " GA_PARENT: " << hex << _hParent  << dec);
+          TRACE_MSG("!!!" <<  hex << _hTemp << " GWL_HWNDPARENT: " << hex << _hParent2  << dec);
         }
     }
     
@@ -289,7 +302,7 @@ BreakWindow::create_lock_button()
   Gtk::Button *ret;
   if (System::is_lockable())
     {
-      ret = Gtk::manage(GtkUtil::create_image_button(_("Lock"), "lock.png"));
+      ret = Gtk::manage(GtkUtil::create_image_button(_("_Lock"), "lock.png"));
       ret->signal_clicked()
         .connect(sigc::mem_fun(*this, &BreakWindow::on_lock_button_clicked));
       GTK_WIDGET_UNSET_FLAGS(ret->gobj(), GTK_CAN_FOCUS);
@@ -308,7 +321,7 @@ BreakWindow::create_shutdown_button()
   Gtk::Button *ret;
   if (System::is_shutdown_supported())
     {
-      ret = Gtk::manage(GtkUtil::create_image_button(_("Shut down"), "shutdown.png"));
+      ret = Gtk::manage(GtkUtil::create_image_button(_("Shut _down"), "shutdown.png"));
       ret->signal_clicked()
         .connect(sigc::mem_fun(*this, &BreakWindow::on_shutdown_button_clicked));
       GTK_WIDGET_UNSET_FLAGS(ret->gobj(), GTK_CAN_FOCUS);
@@ -325,10 +338,11 @@ Gtk::Button *
 BreakWindow::create_skip_button()
 {
   Gtk::Button *ret;
-  ret = Gtk::manage(GtkUtil::create_custom_stock_button(_("Skip"), Gtk::Stock::CLOSE));
+  ret = Gtk::manage(GtkUtil::create_custom_stock_button(_("_Skip"), Gtk::Stock::CLOSE));
   ret->signal_clicked()
     .connect(sigc::mem_fun(*this, &BreakWindow::on_skip_button_clicked));
   GTK_WIDGET_UNSET_FLAGS(ret->gobj(), GTK_CAN_FOCUS);
+
   return ret;
 }
 
@@ -338,7 +352,7 @@ Gtk::Button *
 BreakWindow::create_postpone_button()
 {
   Gtk::Button *ret;
-  ret = Gtk::manage(GtkUtil::create_custom_stock_button(_("Postpone"), Gtk::Stock::REDO));
+  ret = Gtk::manage(GtkUtil::create_custom_stock_button(_("_Postpone"), Gtk::Stock::REDO));
   ret->signal_clicked()
     .connect(sigc::mem_fun(*this, &BreakWindow::on_postpone_button_clicked));
   GTK_WIDGET_UNSET_FLAGS(ret->gobj(), GTK_CAN_FOCUS);
@@ -461,6 +475,9 @@ BreakWindow::create_break_buttons(bool lockable,
 {
   Gtk::HButtonBox *box = NULL;
 
+  accel_group = Gtk::AccelGroup::create();
+  add_accel_group(accel_group);
+  
   if ((break_flags != BREAK_FLAGS_NONE) || lockable || shutdownable)
     {
       box = new Gtk::HButtonBox(Gtk::BUTTONBOX_END, 6);
@@ -471,13 +488,13 @@ BreakWindow::create_break_buttons(bool lockable,
           shutdown_button = create_shutdown_button();
           if (shutdown_button != NULL)
             {
-				box->pack_end(*shutdown_button, Gtk::PACK_SHRINK, 0);
+              box->pack_end(*shutdown_button, Gtk::PACK_SHRINK, 0);
             }
         }
 
       if (lockable)
         {
-          Gtk::Button *lock_button = create_lock_button();
+          lock_button = create_lock_button();
           if (lock_button != NULL)
             {
               box->pack_end(*lock_button, Gtk::PACK_SHRINK, 0);
@@ -486,13 +503,13 @@ BreakWindow::create_break_buttons(bool lockable,
 
       if ((break_flags & BREAK_FLAGS_SKIPPABLE) != 0)
         {
-          Gtk::Button *skip_button = create_skip_button();
+          skip_button = create_skip_button();
           box->pack_end(*skip_button, Gtk::PACK_SHRINK, 0);
         }
       
-        if ((break_flags & BREAK_FLAGS_POSTPONABLE) != 0)
+      if ((break_flags & BREAK_FLAGS_POSTPONABLE) != 0)
         {
-          Gtk::Button *postpone_button = create_postpone_button();
+          postpone_button = create_postpone_button();
           box->pack_end(*postpone_button, Gtk::PACK_SHRINK, 0);
         }
     }
@@ -575,14 +592,51 @@ BreakWindow::destroy()
 void
 BreakWindow::refresh()
 {
-  update_break_window();
+  TRACE_ENTER("BreakWindow::refresh");
   
- #ifdef PLATFORM_OS_WIN32
-   if (block_mode != GUIConfig::BLOCK_MODE_NONE)
-     {
-       WindowHints::set_always_on_top(this, true);
-     }
- #endif
+  update_break_window();
+
+#ifdef PLATFORM_OS_WIN32
+  ICore *core = CoreFactory::get_core();
+  bool user_active = core->is_user_active();
+
+  // GTK keyboard shortcuts can be accessed by using the ALT key. This appear
+  // to be non-standard behaviour on windows, so make shortcuts available
+  // without ALT after the user is idle for 5s
+  if (!user_active && !accel_added)
+    {
+      IBreak *b = core->get_break(BreakId(break_id));
+      assert(b != NULL);
+
+      TRACE_MSG(b->get_elapsed_idle_time());
+      if (b->get_elapsed_idle_time() > 5)
+        {
+          if (postpone_button != NULL)
+            {
+              GtkUtil::update_mnemonic(postpone_button, accel_group);
+            }
+          if (skip_button != NULL)
+            {
+              GtkUtil::update_mnemonic(skip_button, accel_group);
+            }
+          if (shutdown_button != NULL)
+            {
+              GtkUtil::update_mnemonic(shutdown_button, accel_group);
+            }
+          if (lock_button != NULL)
+            {
+              GtkUtil::update_mnemonic(lock_button, accel_group);
+            }
+          accel_added = true;
+        }
+    }
+
+  if (block_mode != GUIConfig::BLOCK_MODE_NONE)
+    {
+      WindowHints::set_always_on_top(this, true);
+    }
+#endif
+  TRACE_EXIT();
 }
 
 Glib::RefPtr<Gdk::Window>
@@ -592,7 +646,6 @@ BreakWindow::get_gdk_window()
 }
 
 
-
 void
 BreakWindow::update_break_window()
 {
