@@ -1,6 +1,6 @@
 // GUI.cc --- The WorkRave GUI
 //
-// Copyright (C) 2001 - 2010 Rob Caelers & Raymond Penners
+// Copyright (C) 2001 - 2011 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -70,6 +70,7 @@
 #include "WindowHints.hh"
 #include "Locale.hh"
 #include "Session.hh"
+#include "TimerBoxControl.hh"
 
 #if defined(PLATFORM_OS_WIN32)
 #include "W32AppletWindow.hh"
@@ -138,7 +139,8 @@ GUI::GUI(int argc, char **argv) :
   grab_handle(NULL),
   status_icon(NULL),
   applet_control(NULL),
-  muted(false)
+  muted(false),
+  closewarn_shown(false)
 {
   TRACE_ENTER("GUI:GUI");
 
@@ -220,6 +222,7 @@ GUI::main()
   init_dbus();
   init_session();
   init_gui();
+  init_startup_warnings();
   
   on_timer();
 
@@ -290,6 +293,27 @@ GUI::close_main_window()
 }
 
 
+//! The user close the main window.
+void
+GUI::main_window_closed()
+{
+  TRACE_ENTER("GUI::main_window_closed");
+  if (status_icon)
+    {
+      bool closewarn = false;
+      CoreFactory::get_configurator()->get_value(GUIConfig::CFG_KEY_CLOSEWARN_ENABLED, closewarn);
+      TRACE_MSG(closewarn);
+      if (closewarn && !closewarn_shown)
+        {
+          status_icon->show_balloon(_("Workrave is still running. "
+                                      "You can access Workrave by clicking on the white sheep icon."));
+          closewarn_shown =  true;
+        }
+    }
+  TRACE_EXIT();
+}
+
+
 //! Periodic heartbeat.
 bool
 GUI::on_timer()
@@ -323,12 +347,11 @@ GUI::on_timer()
 
   if (active_break_count == 0 && muted)
     {
-      ICore *core = CoreFactory::get_core();
       bool user_active = core->is_user_active();
 
       if (user_active)
         {
-          sound_player->set_mute(false);
+          sound_player->restore_mute();
           muted = false;
         }
     }
@@ -801,8 +824,14 @@ GUI::init_gui()
   menus->resync();
 
   // Status icon
+  bool tray_icon_enabled = GUIConfig::get_trayicon_enabled();
+  if (!tray_icon_enabled)
+    {
+      // Recover from bug in 1.9.3 where tray icon AND mainwindow could be disabled
+      TimerBoxControl::set_enabled("main_window", true);
+    }
   status_icon = new StatusIcon(*main_window);
-  status_icon->set_visible(GUIConfig::get_trayicon_enabled());
+  status_icon->set_visible(tray_icon_enabled);
   CoreFactory::get_configurator()->add_listener(GUIConfig::CFG_KEY_TRAYICON_ENABLED, this);
   
 #ifdef HAVE_DBUS
@@ -859,6 +888,16 @@ GUI::init_dbus()
 #endif
 }
 
+void
+GUI::init_startup_warnings()
+{
+  OperationMode mode = core->get_operation_mode();
+  if (mode != OPERATION_MODE_NORMAL)
+    {
+      Glib::signal_timeout().connect(sigc::mem_fun(*this, &GUI::on_operational_mode_warning_timer), 5000);
+    }
+}
+
 
 //! Returns a break window for the specified break.
 IBreakWindow *
@@ -914,9 +953,21 @@ GUI::core_event_notify(const CoreEvent event)
       if (event >= CORE_EVENT_SOUND_FIRST &&
           event <= CORE_EVENT_SOUND_LAST)
         {
+          bool mute = false;
           SoundEvent snd = (SoundEvent) ( (int)event - CORE_EVENT_SOUND_FIRST);
-          TRACE_MSG("play");
-          sound_player->play_sound(snd);
+          TRACE_MSG("play " << event);
+
+          if (event == CORE_EVENT_SOUND_REST_BREAK_STARTED ||
+              event == CORE_EVENT_SOUND_DAILY_LIMIT)
+            {
+              CoreFactory::get_configurator()->get_value(SoundPlayer::CFG_KEY_SOUND_MUTE, mute);
+              if (mute)
+                {
+                  muted = true;
+                }
+            }
+          TRACE_MSG("Mute after playback " << mute);
+          sound_player->play_sound(snd, mute);
         }
     }
 
@@ -972,6 +1023,8 @@ GUI::config_changed_notify(const std::string &key)
 
           if (!tray)
             {
+              TimerBoxControl::set_enabled("main_window", true);
+              
               AppletControl *applet_control = get_applet_control();
               if (applet_control != NULL)
                 {
@@ -1038,7 +1091,8 @@ GUI::create_break_window(BreakId break_id, BreakHint break_hint)
 
   if (break_hint & BREAK_HINT_NATURAL_BREAK)
     {
-      break_flags |=  (BreakWindow::BREAK_FLAGS_NO_EXERCISES | BreakWindow::BREAK_FLAGS_NATURAL);
+      break_flags |=  (BreakWindow::BREAK_FLAGS_NO_EXERCISES | BreakWindow::BREAK_FLAGS_NATURAL |
+                       BreakWindow::BREAK_FLAGS_POSTPONABLE);
     }
   
   active_break_id = break_id;
@@ -1055,17 +1109,6 @@ GUI::create_break_window(BreakId break_id, BreakHint break_hint)
 
   active_break_count = num_heads;
 
-  if (break_id == BREAK_ID_REST_BREAK ||
-      break_id == BREAK_ID_DAILY_LIMIT)
-    {
-      bool mute = false;
-      CoreFactory::get_configurator()->get_value(SoundPlayer::CFG_KEY_SOUND_MUTE, mute);
-      if (mute)
-        {
-          muted = !sound_player->set_mute(true);
-        }
-    }
-  
   TRACE_EXIT();
 }
 
@@ -1252,11 +1295,8 @@ GUI::grab()
 {
   if (break_windows != NULL && active_break_count > 0)
     {
-#ifdef PLATFORM_OS_WIN32_NATIVE
-		GdkWindow *windows[BREAK_ID_SIZEOF];
-#else
-	  GdkWindow *windows[active_break_count];
-#endif
+      GdkWindow **windows = new GdkWindow *[active_break_count];
+
       for (int i = 0; i < active_break_count; i++)
         {
           Glib::RefPtr<Gdk::Window> window = break_windows[i]->get_gdk_window();
@@ -1277,6 +1317,8 @@ GUI::grab()
             }
 #endif
         }
+
+      delete [] windows;
     }
   return grab_handle != NULL;
 }
@@ -1342,6 +1384,23 @@ GUI::on_grab_retry_timer()
 #endif
 
 
+bool
+GUI::on_operational_mode_warning_timer()
+{
+  OperationMode mode = core->get_operation_mode();
+  if (mode == OPERATION_MODE_SUSPENDED)
+    {
+      status_icon->show_balloon(_("Workrave is in suspended mode. "
+                                  "Mouse and keyboard activity will not be monitored."));
+    }
+  else if (mode == OPERATION_MODE_QUIET)
+    {
+      status_icon->show_balloon(_("Workrave is in quiet mode. "
+                                  "No break windows will appear."));
+    }
+  return false;
+}
+
 HeadInfo &
 GUI::get_head(int head)
 {
@@ -1467,15 +1526,9 @@ GUI::get_timers_tooltip()
   const char *labels[] = { _("Micro-break"), _("Rest break"), _("Daily limit") };
   string tip = "";
 
-  ICore *core = CoreFactory::get_core();
-
   OperationMode mode = core->get_operation_mode();
   switch (mode)
     {
-    case OPERATION_MODE_NORMAL:
-      tip = "Workrave";
-      break;
-        
     case OPERATION_MODE_SUSPENDED:
       tip = string(_("Mode: ")) +   _("Suspended");
       break;
@@ -1484,7 +1537,12 @@ GUI::get_timers_tooltip()
       tip = string(_("Mode: ")) +   _("Quiet");
       break;
 
+    case OPERATION_MODE_NORMAL:
     default:
+#if !defined(PLATFORM_OS_WIN32)
+          // Win32 tip is limited in length
+      tip = "Workrave";
+#endif      
       break;
     }
   
@@ -1510,13 +1568,6 @@ GUI::get_timers_tooltip()
               text = Text::time_to_string(activeTime);
             }
 
-#if !defined(PLATFORM_OS_WIN32)
-          // Win32 tip is limited in length
-          if (tip == "")
-            {
-              tip = "Workrave";
-            }
-#endif
           if (tip != "")
             {
               tip += "\n";
@@ -1600,6 +1651,8 @@ GUI::win32_filter_func (void     *xevent,
             break;
 
           case PBT_APMRESUMESUSPEND:
+          case PBT_APMRESUMEAUTOMATIC:
+          case PBT_APMRESUMECRITICAL:
             {
               TRACE_MSG("Resume suspend");
               ICore *core = CoreFactory::get_core();
