@@ -1,6 +1,6 @@
 // GnomeAppletWindow.cc --- Applet info Window
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Rob Caelers & Raymond Penners
+// Copyright (C) 2001 - 2010 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -267,6 +267,9 @@ GnomeAppletWindow::set_menu_active(int menu, bool active)
             case MENUSYNC_MODE_QUIET:
               applet_control->SetMenuStatus("/commands/Quiet", active);
               break;
+            case MENUSYNC_MODE_READING:
+              applet_control->SetMenuStatus("/commands/ReadingMode", active);
+              break;
             case MENUSYNC_SHOW_LOG:
               applet_control->SetMenuStatus("/commands/ShowLog", active);
               break;
@@ -302,6 +305,9 @@ GnomeAppletWindow::get_menu_active(int menu)
             case MENUSYNC_MODE_QUIET:
               applet_control->GetMenuStatus("/commands/Quiet", ret);
               break;
+            case MENUSYNC_MODE_READING:
+              applet_control->GetMenuStatus("/commands/ReadingMode", ret);
+              break;
             case MENUSYNC_SHOW_LOG:
               applet_control->GetMenuStatus("/commands/ShowLog", ret);
               break;
@@ -340,8 +346,7 @@ GnomeAppletWindow::set_applet_size(int size)
 {
   TRACE_ENTER_MSG("GnomeAppletWindow::set_applet_size", size);
 
-  if (plug != NULL)
-    {
+  if (plug != NULL)    {
       plug->queue_resize();
     }
 
@@ -360,7 +365,12 @@ GnomeAppletWindow::set_applet_size(int size)
 void
 GnomeAppletWindow::set_applet_background(int type, GdkColor &color, long xid)
 {
-  TRACE_ENTER_MSG("GnomeAppletWindow::set_applet_pixmap", xid);
+  TRACE_ENTER_MSG("GnomeAppletWindow::set_applet_background", type << " " << xid 
+                  << " " << color.pixel
+                  << " " << color.red 
+                  << " " << color.green
+                  << " " << color.blue
+                  );
 
   if (plug == NULL)
     {
@@ -408,31 +418,31 @@ GnomeAppletWindow::set_applet_background(int type, GdkColor &color, long xid)
         }
     }
 
-  GtkRcStyle *rc_style = gtk_rc_style_new();
+  GtkRcStyle *rc_style = NULL;
   GtkStyle *style = NULL;
 
-  gtk_widget_set_style (widget, NULL);
+  gtk_widget_set_style(widget, NULL);
+  rc_style = gtk_rc_style_new();
   gtk_widget_modify_style (widget, rc_style);
+  g_object_unref(rc_style);
 
   switch (type)
     {
     case 0: //PANEL_NO_BACKGROUND:
       break;
     case 1: //PANEL_COLOR_BACKGROUND:
-      gtk_widget_modify_bg (widget,
-                            GTK_STATE_NORMAL, &color);
+      gtk_widget_modify_bg(widget, GTK_STATE_NORMAL, &color);
       break;
     case 2: //PANEL_PIXMAP_BACKGROUND:
-      style = gtk_style_copy (widget->style);
+      style = gtk_style_copy(widget->style);
       if (style->bg_pixmap[GTK_STATE_NORMAL])
-        g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
-      style->bg_pixmap[GTK_STATE_NORMAL] = (GdkPixmap *)g_object_ref (pixmap);
-      gtk_widget_set_style (widget, style);
-      g_object_unref (style);
+        g_object_unref(style->bg_pixmap[GTK_STATE_NORMAL]);
+      style->bg_pixmap[GTK_STATE_NORMAL] = (GdkPixmap *)g_object_ref(pixmap);
+      gtk_widget_set_style(widget, style);
+      g_object_unref(style);
       break;
     }
 
-  gtk_rc_style_unref (rc_style);
 
   if (pixmap != NULL)
     {
