@@ -1,6 +1,6 @@
 // MainWindow.cc --- Main info Window
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -300,9 +300,22 @@ MainWindow::update()
 }
 
 
-void MainWindow::on_activate()
+void
+MainWindow::on_activate()
 {
-  if (GTK_WIDGET_VISIBLE(GTK_WIDGET(gobj())))
+  TRACE_ENTER("MainWindow::on_activate");
+
+#ifdef PLATFORM_OS_WIN32  
+  GtkWidget *window = Gtk::Widget::gobj();
+  GdkWindow *gdk_window = window->window;
+  HWND hwnd = (HWND) GDK_WINDOW_HWND(gdk_window);
+  
+  bool visible = IsWindowVisible(hwnd);
+#else
+  bool visible = GTK_WIDGET_VISIBLE(GTK_WIDGET(gobj()));
+#endif
+
+  if (visible)
     {
       close_window();
     }
@@ -310,6 +323,7 @@ void MainWindow::on_activate()
     {
       open_window();
     }
+  TRACE_EXIT();
 }
 
 
@@ -373,6 +387,7 @@ MainWindow::close_window()
       iconify();
     }
 #endif
+  GUIConfig::set_trayicon_enabled(true);
   TRACE_EXIT();
 }
 
@@ -382,13 +397,13 @@ bool
 MainWindow::on_delete_event(GdkEventAny *)
 {
   TRACE_ENTER("MainWindow::on_delete_event");
-
-#ifdef PLATFORM_OS_WIN32
-  win32_show(false);
-#else
   GUI *gui = GUI::get_instance();
   assert(gui != NULL);
 
+#ifdef PLATFORM_OS_WIN32
+  win32_show(false);
+  gui->main_window_closed();
+#else
 #if defined(HAVE_GNOME) || defined(HAVE_KDE)
   bool terminate = true;
   AppletControl *applet_control = gui->get_applet_control();
