@@ -1,6 +1,6 @@
 // PreferencesDialog.cc --- Preferences dialog
 //
-// Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2009 Raymond Penners <raymond@dotsphinx.com>
+// Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2010 Raymond Penners <raymond@dotsphinx.com>
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -291,6 +291,13 @@ PreferencesDialog::create_gui_page()
   autostart_cb->set_active(rc);
 #endif  
 
+  Gtk::Label *trayicon_lab = Gtk::manage(GtkUtil::create_label(_("Show system tray icon"), false));
+  trayicon_cb = Gtk::manage(new Gtk::CheckButton());
+  trayicon_cb->add(*trayicon_lab);
+  connector->connect(GUIConfig::CFG_KEY_TRAYICON_ENABLED, dc::wrap(trayicon_cb));
+
+  panel->add(*trayicon_cb);
+
   panel->set_border_width(12);
   return panel;
 }
@@ -331,7 +338,7 @@ PreferencesDialog::create_sounds_page()
   GUI *gui = GUI::get_instance();
   SoundPlayer *snd = gui->get_sound_player();
   
-  if (snd->capability(SoundPlayer::SOUND_CAP_VOLUME))
+  if (snd->capability(SOUND_CAP_VOLUME))
     {
       // Volume 
       sound_volume_scale =  Gtk::manage(new Gtk:: HScale(0.0, 100.0, 0.0));
@@ -343,8 +350,18 @@ PreferencesDialog::create_sounds_page()
 
   hig->add(_("Sound:"), *sound_button);
 
+  if (snd->capability(SOUND_CAP_MUTE))
+    {
+      // Volume 
+      mute_cb = Gtk::manage(new Gtk::CheckButton
+                            (_("Mute sounds during rest break and daily limit")));
+  
+      connector->connect(SoundPlayer::CFG_KEY_SOUND_MUTE, dc::wrap(mute_cb));
 
-  if (snd->capability(SoundPlayer::SOUND_CAP_EDIT))
+      hig->add(*mute_cb, true, true);
+    }
+
+  if (snd->capability(SOUND_CAP_EDIT))
     {
       // Sound themes
       hig = Gtk::manage(new HigCategoryPanel(_("Sound Events"), true));
@@ -362,13 +379,13 @@ PreferencesDialog::create_sounds_page()
       sound_store = Gtk::ListStore::create(sound_model);
       sound_treeview.set_model(sound_store);
 
-      for (unsigned int i = 0; i < SoundPlayer::SOUND_EXERCISE_MAX; i++)
+      for (unsigned int i = 0; i < SOUND_MAX; i++)
         {
           Gtk::TreeModel::iterator iter = sound_store->append();
           Gtk::TreeModel::Row row = *iter;
 
           bool sound_enabled = false;
-          snd->get_sound_enabled((SoundPlayer::SoundEvent)i, sound_enabled);
+          snd->get_sound_enabled((SoundEvent)i, sound_enabled);
 
           row[sound_model.enabled] = sound_enabled;
           row[sound_model.selectable] = true;
@@ -704,7 +721,7 @@ PreferencesDialog::on_sound_enabled(const Glib::ustring &path_string)
       GUI *gui = GUI::get_instance();
       SoundPlayer *snd = gui->get_sound_player();
   
-      snd->set_sound_enabled((SoundPlayer::SoundEvent)(int)row[sound_model.event],
+      snd->set_sound_enabled((SoundEvent)(int)row[sound_model.event],
                              row[sound_model.enabled]);
     }
 }
@@ -767,7 +784,7 @@ PreferencesDialog::on_sound_filechooser_select()
 
         GUI *gui = GUI::get_instance();
         SoundPlayer *snd = gui->get_sound_player();
-        snd->set_sound_wav_file( (SoundPlayer::SoundEvent)(int)row[sound_model.event], filename);
+        snd->set_sound_wav_file( (SoundEvent)(int)row[sound_model.event], filename);
         TRACE_MSG(filename);
         update_theme_selection();
       }
