@@ -1,6 +1,6 @@
 // PreludeWindow.cc
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2009 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2011 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -134,23 +134,23 @@ PreludeWindow::PreludeWindow(HeadInfo &head, BreakId break_id)
   HWND _hParent = GetAncestor( _hwnd, GA_PARENT );
   HWND _hDesktop = GetDesktopWindow();
   
-  TRACE_MSG("PreludeWindow created" <<  hex << _hwnd);
+  TRACE_MSG("PreludeWindow created" <<  hex << _hwnd  << dec);
   
   if (_hwnd != _scope)
     {
-      TRACE_MSG( "!!!!!!!!!!!!!!!" <<  "Scope issue: " << hex << _scope );
+      TRACE_MSG( "!!!!!!!!!!!!!!!" <<  "Scope issue: " << hex << _scope  << dec);
     }
   
   if (_hwnd != _hRoot)
     {
-      TRACE_MSG( "GetDesktopWindow()" <<  hex << _hDesktop );
-      TRACE_MSG( "!!!!!!!!!!!!!!!" <<  "PreludeWindow GA_ROOT: " << hex << _hRoot );
+      TRACE_MSG( "GetDesktopWindow()" <<  hex << _hDesktop  << dec);
+      TRACE_MSG( "!!!!!!!!!!!!!!!" <<  "PreludeWindow GA_ROOT: " << hex << _hRoot  << dec);
     }
   
   if( _hParent != _hDesktop )
     {
-      TRACE_MSG( "GetDesktopWindow()" <<  hex << _hDesktop );
-      TRACE_MSG( "!!!!!!!!!!!!!!!" << "PreludeWindow GA_PARENT: " << hex << _hParent );
+      TRACE_MSG( "GetDesktopWindow()" <<  hex << _hDesktop  << dec);
+      TRACE_MSG( "!!!!!!!!!!!!!!!" << "PreludeWindow GA_PARENT: " << hex << _hParent  << dec);
       
       HWND _hTemp;
       while( IsWindow( _hParent ) && _hParent != _hDesktop )
@@ -160,8 +160,8 @@ PreludeWindow::PreludeWindow(HeadInfo &head, BreakId break_id)
           HWND _hParent2 = (HWND)GetWindowLong( _hTemp, GWL_HWNDPARENT );
           if( _hParent == _hTemp )
             break;
-          TRACE_MSG("!!!!!!!!!!!!!!!" << hex << _hTemp << " GA_PARENT: " << hex << _hParent);
-          TRACE_MSG("!!!!!!!!!!!!!!!" << hex << _hTemp << " GWL_HWNDPARENT: " << hex << _hParent2);
+          TRACE_MSG("!!!!!!!!!!!!!!!" << hex << _hTemp << " GA_PARENT: " << hex << _hParent  << dec);
+          TRACE_MSG("!!!!!!!!!!!!!!!" << hex << _hTemp << " GWL_HWNDPARENT: " << hex << _hParent2  << dec);
         }
     }
 #endif
@@ -380,9 +380,26 @@ PreludeWindow::on_frame_flash(bool frame_visible)
 void
 PreludeWindow::init_avoid_pointer()
 {
+  TRACE_ENTER("PreludeWindow::init_avoid_pointer");
 #ifdef PLATFORM_OS_WIN32
   if (! avoid_signal.connected())
     {
+      POINT p;
+      GetCursorPos(&p);
+      
+      Glib::RefPtr<Gdk::Display> display = Gdk::Display::get_default();
+      int x, y;
+      Gdk::ModifierType mod;
+      display->get_pointer(x, y, mod);
+
+      TRACE_MSG("p " << p.x << " " << p.y);
+      TRACE_MSG("d " << x << " " << y);
+
+      gdk_offset_x = p.x - x;
+      gdk_offset_y = p.y - y;
+
+      TRACE_MSG("offset " << gdk_offset_x << " " << gdk_offset_y); 
+     
       avoid_signal = Glib::signal_timeout()
         .connect(sigc::mem_fun(*this, &PreludeWindow::on_avoid_pointer_timer),
                  150);
@@ -397,6 +414,7 @@ PreludeWindow::init_avoid_pointer()
     }
 #endif
   did_avoid = false;
+  TRACE_EXIT();
 }
 
 #ifndef PLATFORM_OS_WIN32
@@ -429,6 +447,7 @@ PreludeWindow::avoid_pointer(int px, int py)
   // Set gravitiy, otherwise, get_position() returns weird winy.
   set_gravity(Gdk::GRAVITY_STATIC);
   get_position(winx, winy);
+  TRACE_MSG("pos " << winx << " " << winy);
   if (px < winx || px > winx+width || py < winy || py > winy+height)
     return;
 #else
@@ -441,6 +460,8 @@ PreludeWindow::avoid_pointer(int px, int py)
   int screen_height = head.get_height();
   int top_y = head.get_y() + SCREEN_MARGIN;
   int bottom_y = head.get_y() + screen_height - height - SCREEN_MARGIN;
+  TRACE_MSG("geom3" << screen_height << " " << top_y << " " << bottom_y);
+  
   if (winy < top_y + SCREEN_MARGIN)
     {
       winy = bottom_y;
@@ -470,6 +491,7 @@ PreludeWindow::avoid_pointer(int px, int py)
 bool
 PreludeWindow::on_avoid_pointer_timer()
 {
+  TRACE_ENTER("PreludeWindow::on_avoid_pointer_timer");
   /*
     display->get_pointer reads low-level keyboard state, and that's a
     problem for anti-hook monitors. use GetCursorPos() instead.
@@ -477,9 +499,10 @@ PreludeWindow::on_avoid_pointer_timer()
   POINT p;
   if (GetCursorPos(&p))
     {
-      avoid_pointer(p.x, p.y);
+     avoid_pointer(p.x - gdk_offset_x, p.y - gdk_offset_y);
     }
 
+  TRACE_EXIT();
   return true;
 }
 #endif
