@@ -27,6 +27,10 @@
 
 #include "debug.hh"
 
+#ifdef PLATFORM_OS_WIN32_NATIVE
+#undef HAVE_UNISTD_H
+#endif
+
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
