@@ -1,6 +1,6 @@
 // main.cc --- Main
 //
-// Copyright (C) 2001, 2002, 2003, 2006, 2007, 2008, 2009 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2006, 2007, 2008, 2009, 2010 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -41,12 +41,17 @@ extern "C" int run(int argc, char **argv);
 int
 run(int argc, char **argv)
 {
+
 #if defined(PLATFORM_OS_WIN32) && !defined(PLATFORM_OS_WIN32_NATIVE)
+	SetUnhandledExceptionFilter(exception_filter);
+
+#if defined(THIS_SEEMS_TO_CAUSE_PROBLEMS_ON_WINDOWS_SERVER)
   // Enable Windows structural exception handling.
   __try1(exception_handler);
 #endif
-
-#ifndef NDEBUG 
+#endif
+  
+#ifdef TRACING 
   Debug::init();
 #endif
   
@@ -60,16 +65,18 @@ run(int argc, char **argv)
 
   delete gui;
 
+#if defined(THIS_SEEMS_TO_CAUSE_PROBLEMS_ON_WINDOWS_SERVER)
 #if defined(PLATFORM_OS_WIN32) && !defined(PLATFORM_OS_WIN32_NATIVE)
   // Disable Windows structural exception handling.
   __except1;
+#endif
 #endif
   
   return 0;
 }
 
 
-#if (!defined(PLATFORM_OS_WIN32)) || (!defined(PLATFORM_OS_WIN32_NATIVE) && !defined(NDEBUG))
+#if !defined(PLATFORM_OS_WIN32) // || (!defined(PLATFORM_OS_WIN32_NATIVE) && !defined(NDEBUG))
 int
 main(int argc, char **argv)
 {
@@ -86,6 +93,10 @@ int WINAPI WinMain (HINSTANCE hInstance,
                     PSTR szCmdLine,
                     int iCmdShow)
 {
+  (void) hInstance;
+  (void) hPrevInstance;
+  (void) iCmdShow;
+
   char *argv[] = { szCmdLine };
   
   // InnoSetup: [...] requires that you add code to your application
