@@ -1,6 +1,6 @@
 // W32AppletMenu.cc --- Menus using W32Applet+
 //
-// Copyright (C) 2001 - 2010 Rob Caelers & Raymond Penners
+// Copyright (C) 2001 - 2011 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -90,7 +90,7 @@ W32AppletMenu::resync(OperationMode mode, UsageMode usage, bool show_log)
       W32AppletWindow *w32aw = applet_window;
       w32aw->init_menu(cmd_win);
 
-      w32aw->add_menu(_("Open"), Menus::MENU_COMMAND_OPEN, 0);
+      w32aw->add_menu(_("_Open"), Menus::MENU_COMMAND_OPEN, 0);
       w32aw->add_menu(_("Preferences"), Menus::MENU_COMMAND_PREFERENCES, 0);
       w32aw->add_menu(_("_Rest break"), Menus::MENU_COMMAND_REST_BREAK, 0);
       w32aw->add_menu(_("Exercises"), Menus::MENU_COMMAND_EXERCISES, 0);
