@@ -1,6 +1,6 @@
 // AppletWindow.cc --- Applet info Window
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -35,19 +35,25 @@ W32AppletWindow::W32AppletWindow()
 {
   TRACE_ENTER("W32AppletWindow::W32AppletWindow");
 
+  memset(&local_heartbeat_data, 0, sizeof(AppletHeartbeatData));
+  memset(&local_menu_data, 0, sizeof(AppletMenuData));
+  memset(&heartbeat_data, 0, sizeof(AppletHeartbeatData));
+  memset(&menu_data, 0, sizeof(AppletMenuData));
+  
   thread_id = 0;
   thread_handle = NULL;
   timer_box_view = this;
   applet_window = NULL;
   heartbeat_data.enabled = false;
+  local_applet_window = NULL;
   init_menu(NULL);
 
+  ::InitializeCriticalSection(&heartbeat_data_lock);
+  heartbeat_data_event = ::CreateEvent(NULL, FALSE, FALSE, NULL);
+
   // Intentionally last line, as this one calls W32AW::set_enabled(), e.g.
   timer_box_control = new TimerBoxControl("applet", *this);
 
-  ::InitializeCriticalSection(&heartbeat_data_lock);
-  heartbeat_data_event = ::CreateEvent(NULL, FALSE, FALSE, NULL);
-  
   TRACE_EXIT();
 }
 
@@ -103,11 +109,11 @@ W32AppletWindow::set_slot(BreakId id, int slot)
 
 void
 W32AppletWindow::set_time_bar(BreakId id,
-                                 std::string text,
-                                 ITimeBar::ColorId primary_color,
-                                 int primary_val, int primary_max,
-                                 ITimeBar::ColorId secondary_color,
-                                 int secondary_val, int secondary_max)
+                              std::string text,
+                              ITimeBar::ColorId primary_color,
+                              int primary_val, int primary_max,
+                              ITimeBar::ColorId secondary_color,
+                              int secondary_val, int secondary_max)
 {
   TRACE_ENTER_MSG("W32AppletWindow::set_time_bar", int(id) << "=" << text);
   strncpy(heartbeat_data.bar_text[id], text.c_str(), APPLET_BAR_TEXT_MAX_LENGTH-1);
